# plz
![licesns](https://img.shields.io/github/license/royreznik/plz)
![python](https://img.shields.io/pypi/pyversions/plz)
![code style](https://camo.githubusercontent.com/d91ed7ac7abbd5a6102cbe988dd8e9ac21bde0a73d97be7603b891ad08ce3479/68747470733a2f2f696d672e736869656c64732e696f2f62616467652f636f64652532307374796c652d626c61636b2d3030303030302e737667)
![lastcommit](https://img.shields.io/github/last-commit/royreznik/plz)
[![Python assspplication](https://github.com/royreznik/plz/actions/workflows/ci.yml/badge.svg?branch=master)](https://github.com/royreznik/plz/actions/workflows/ci.yml)
![downloads](https://img.shields.io/pypi/dm/plz)

Lightweight and simple python virtual environment and dependencies manager 

## Install
```bash
pip install plz
```

## Developing
```bash
make install
make test
make format
make lint
```
